lux::graphics

Struct Ellipse

pub struct Ellipse<'a, C: 'a> { /* private fields */ }
An ellipse that can be drawn to the screen.

Implementations

Source

impl<'a, C> Ellipse<'a, C>

pub fn segments(&mut self, segments: u16) -> &mut Self

Sets the number of segments that are used to approximate a circle.

Example
use lux::prelude::*;
use lux::graphics::ColorVertex;

let mut window = Window::new().unwrap();
let mut frame = window.frame();
let (x, y, size) = (10.0, 10.0, 50.0);
// draw a pentagon
frame.circle(x, y, size).segments(5).draw();
pub fn line_length(&mut self, line_length: u16) -> &mut Self

Instead of

Source

impl<'a, C> Ellipse<'a, C>
where C: Canvas + 'a,

pub fn fill(&mut self)

Fills in the ellipse with a solid color.