pub struct Ellipse<'a, C: 'a> { /* private fields */ }Expand description
An ellipse that can be drawn to the screen.
Implementations
Sourceimpl<'a, C> Ellipse<'a, C>
impl<'a, C> Ellipse<'a, C>
Sourcepub fn segments(&mut self, segments: u16) -> &mut Self
pub fn segments(&mut self, segments: u16) -> &mut Self
Sets the number of segments that are used to approximate a circle.
Example
use lux::prelude::*;
use lux::graphics::ColorVertex;
let mut window = Window::new().unwrap();
let mut frame = window.frame();
let (x, y, size) = (10.0, 10.0, 50.0);
// draw a pentagon
frame.circle(x, y, size).segments(5).draw();Sourcepub fn line_length(&mut self, line_length: u16) -> &mut Self
pub fn line_length(&mut self, line_length: u16) -> &mut Self
Instead of